﻿/*
Copyright © 2010 François Karman

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

See <license.txt> for the complete license of the software.
*/

using System.Diagnostics.CodeAnalysis;
using System.Xml;

namespace MSBuild.Mercurial.CodePlex
{
    /// <summary>
    /// Represents the documentation of a task.
    /// </summary>
    public class TaskDocumentation
    {
        /// <summary>
        /// Initializes a new instance of the TaskDocumentation class.
        /// </summary>
        public TaskDocumentation()
        {
            this.Properties = new PropertyCollection();
        }

        /// <summary>
        /// Gets or sets the name of the MSBuild task.
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// Gets or sets the associated Xml comment.
        /// </summary>
        [SuppressMessage(
            "Microsoft.Design",
            "CA1059:MembersShouldNotExposeCertainConcreteTypes",
            Justification = "The interface IXPathNavigeable doesn't provide enought functionalities and can't be serialized")]
        public XmlNode Comment { get; set; }

        /// <summary>
        /// Gets or sets the associated properties / parameters.
        /// </summary>
        [SuppressMessage(
            "Microsoft.Usage",
            "CA2227:CollectionPropertiesShouldBeReadOnly",
            Justification = "Setter is required by the Xml serialization")]
        public PropertyCollection Properties { get; set; }
    }
}
