﻿<?xml version="1.0" encoding="utf-8" ?>
<!--
Copyright © 2010 François Karman

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

See <license.txt> for the complete license of the software.
-->
<xsl:stylesheet version="2.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

  <xsl:output method="html" indent="yes" />

  <xsl:template match="//TaskDocumentation">
    <xsl:apply-templates mode="MainTitle" select="Name" />

    <xsl:apply-templates select="Comment/member/summary" />
    <xsl:value-of select="'&#xa;'" />
    <xsl:value-of select="'&#xa;'" />

    <xsl:apply-templates mode="Inputs" select="Properties[count(PropertyDocumentation[Output='false']) &gt; 0]" />
    <xsl:apply-templates mode="Outputs" select="Properties[count(PropertyDocumentation[Output='true']) &gt; 0]" />

    <xsl:apply-templates select="Comment/member/remarks" />
    <xsl:apply-templates select="Comment/member/example" />
    <xsl:value-of select="'&#xa;'" />
  </xsl:template>

  <xsl:template mode="MainTitle" match="Name">
    <xsl:value-of select="'!! '" />
    <xsl:value-of select="." />
    <xsl:value-of select="' Task'" />
    <xsl:value-of select="'&#xa;&#xa;'" />
  </xsl:template>

  <xsl:template mode="Inputs" match="Properties">
    <xsl:value-of select="'!!! Inputs&#xa;&#xa;'" />
    <xsl:value-of select="'|| Property || Type || Description || Required ||&#xa;'" />
    <xsl:apply-templates select="PropertyDocumentation[Output='false']" />
    <xsl:value-of select="'&#xa;'" />
  </xsl:template>

  <xsl:template mode="Outputs" match="Properties">
    <xsl:value-of select="'!!! Outputs&#xa;&#xa;'" />
    <xsl:value-of select="'|| Property || Type || Description || Required ||&#xa;'" />
    <xsl:apply-templates select="PropertyDocumentation[Output='true']" />
    <xsl:value-of select="'&#xa;'" />
  </xsl:template>

  <xsl:template match="PropertyDocumentation">
    <xsl:value-of select="'| {{'" />
    <xsl:value-of select="Name" />
    <xsl:value-of select="'}} | '" />
    <xsl:value-of select="Type" />
    <xsl:value-of select="' | '" />

    <xsl:variable name="text"
                  select="normalize-space(substring-after(Comment/member/summary, 'Gets or sets'))" />
    <xsl:choose>
      <xsl:when test="contains($text, '[Output].')">
        <xsl:value-of select="normalize-space(substring($text, 1, string-length($text) - 9))" />
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="normalize-space(substring($text, 1, string-length($text) - 1))" />
      </xsl:otherwise>
    </xsl:choose>

    <xsl:value-of select="' | '" />
    <xsl:choose>
      <xsl:when test="normalize-space(Required) = 'true'">
        <xsl:text>*yes*</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>no</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:value-of select="' |&#xa;'" />
  </xsl:template>

  <xsl:template match="remarks">
    <xsl:value-of select="'!!! Remarks&#xa;&#xa;'" />
    <xsl:apply-templates />
    <xsl:value-of select="'&#xa;&#xa;'" />
  </xsl:template>

  <xsl:template match="example">
    <xsl:value-of select="'!!! Sample&#xa;&#xa;'" />
    <xsl:apply-templates />
    <xsl:value-of select="'&#xa;&#xa;'" />
  </xsl:template>

  <xsl:template match="para">
    <xsl:apply-templates />
    <xsl:value-of select="'&#xa;'" />
  </xsl:template>

  <xsl:template match="code">
    <xsl:text>&#xa;{code:xml}</xsl:text>
    <xsl:value-of disable-output-escaping="yes" select="*|text()" />
    <xsl:text>&#xa;{code:xml}</xsl:text>
  </xsl:template>

  <xsl:template match="c">
    <xsl:value-of select="'{{'" />
    <xsl:apply-templates />
    <xsl:value-of select="'}}'" />
  </xsl:template>

  <xsl:template match="see">
    <xsl:value-of select="'{{'" />
    <xsl:value-of select="substring-after(@cref, 'MSBuild.Mercurial.')" />
    <xsl:value-of select="'}}'" />
  </xsl:template>

  <xsl:template match="list[@type = 'bullet']">
    <xsl:value-of select="'&#xa;'" />
    <xsl:for-each select="item">
      <xsl:text>* </xsl:text>
      <xsl:apply-templates />
      <xsl:value-of select="'&#xa;'" />
    </xsl:for-each>
    <xsl:value-of select="'&#xa;'" />
  </xsl:template>

  <xsl:template match="list[@type = 'number']">
    <xsl:value-of select="'&#xa;'" />
    <xsl:for-each select="item">
      <xsl:text># </xsl:text>
      <xsl:apply-templates />
      <xsl:value-of select="'&#xa;'" />
    </xsl:for-each>
    <xsl:value-of select="'&#xa;'" />
  </xsl:template>

  <xsl:template match="text()">
    <xsl:if test="starts-with(., ' ')">
      <xsl:value-of select="' '" />
    </xsl:if>
    <xsl:value-of select="normalize-space(.)" />

    <!-- Test the end of the text as ends-with is not supported in .Net 3.5 -->
    <xsl:if test="contains(substring-after(., normalize-space(.)), ' ') or contains(substring-after(., normalize-space(.)), '&#xa;')">
      <xsl:value-of select="' '" />
    </xsl:if>
  </xsl:template>
</xsl:stylesheet>
