﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using NUnit.Framework;

namespace MSBuild.Mercurial
{
    /// <summary>
    /// Tests the <see cref="AbstractRemoteTask"/> class.
    /// </summary>
    [TestFixture]
    public static class AbstractRemoteTaskTest
    {
        /// <summary>
        /// Tests the <see cref="AbstractRemoteTask.User"/> property.
        /// </summary>
        [Test]
        public static void User()
        {
            RemoteTask instance = new RemoteTask();
            Assert.IsNull(instance.User);
            string expected = "my user";
            instance.User = expected;
            Assert.AreEqual(expected, instance.User);
        }

        /// <summary>
        /// Tests the <see cref="AbstractRemoteTask.Password"/> property.
        /// </summary>
        [Test]
        public static void Password()
        {
            RemoteTask instance = new RemoteTask();
            Assert.IsNull(instance.Password);
            string expected = "my password";
            instance.Password = expected;
            Assert.AreEqual(expected, instance.Password);
        }

        /// <summary>
        /// Tests the <c>AbstractRemoteTask.Repository</c> property
        /// without a user/password definition.
        /// </summary>
        [Test]
        public static void RepositoryWithoutCredential()
        {
            RemoteTask instance = new RemoteTask();
            Assert.IsNull(instance.RemoteRepository);

            // Test with a local repository
            string local = "c:\\local\\path";
            instance.RemoteRepository = local;
            Assert.AreEqual(local, instance.RemoteRepository);

            // Test with a remote repository
            string remote = "http://localhost:8080/test";
            instance.RemoteRepository = remote;
            Assert.AreEqual(remote, instance.RemoteRepository);
        }

        /// <summary>
        /// Tests the <c>AbstractRemoteTask.Repository</c> property
        /// with a user definition only.
        /// </summary>
        [Test]
        public static void RepositoryWithUser()
        {
            RemoteTask instance = new RemoteTask();
            instance.User = "my user";
            Assert.IsNull(instance.RemoteRepository);

            // Test with a local repository
            string local = "c:\\local\\path";
            instance.RemoteRepository = local;
            Assert.AreEqual(local, instance.RemoteRepository);

            // Test with a remote repository
            instance.RemoteRepository = "http://localhost:8080/test";
            Assert.AreEqual("http://my%20user@localhost:8080/test", instance.RemoteRepository);
        }

        /// <summary>
        /// Tests the <c>AbstractRemoteTask.Repository</c> property
        /// with user and password.
        /// </summary>
        [Test]
        public static void RepositoryWithUserAndPassword()
        {
            RemoteTask instance = new RemoteTask();
            instance.User = "my user";
            instance.Password = "my @pass";
            Assert.IsNull(instance.RemoteRepository);

            // Test with a local repository
            string local = "c:\\local\\path";
            instance.RemoteRepository = local;
            Assert.AreEqual(local, instance.RemoteRepository);

            // Test with a remote repository
            instance.RemoteRepository = "http://localhost:8080/test";
            Assert.AreEqual("http://my%20user:my%20%40pass@localhost:8080/test", instance.RemoteRepository);
        }

        /// <summary>
        ///  Implements the <see cref="AbstractRemoteTask"/> class.
        /// </summary>
        private class RemoteTask : AbstractRemoteTask
        {
            /// <summary>
            /// Gets or sets the remote repository path.
            /// </summary>
            public string RemoteRepository
            {
                get { return this.Repository; }
                set { this.Repository = value; }
            }
        }
    }
}
