﻿/*
Copyright © 2010 François Karman

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

See <license.txt> for the complete license of the software.
*/

using System;
using NUnit.Framework;

namespace MSBuild.Mercurial.Command
{
    /// <summary>
    /// Tests the <see cref="ChoiceParameterBuilder"/> class.
    /// </summary>
    [TestFixture]
    public static class ChoiceParameterBuilderTest
    {
        /// <summary>
        /// Tests the <see cref="ChoiceParameterBuilder.CanBuild"/> method.
        /// </summary>
        [Test]
        public static void CanBuild()
        {
            ChoiceParameterBuilder instance = new ChoiceParameterBuilder();
            Assert.IsTrue(instance.CanBuild(typeof(bool)));
            Assert.IsFalse(instance.CanBuild(typeof(string)));
            Assert.IsFalse(instance.CanBuild(null));
        }

        /// <summary>
        /// Tests the <see cref="ChoiceParameterBuilder.Build"/> method.
        /// </summary>
        [Test]
        public static void Build()
        {
            ChoiceParameterBuilder instance = new ChoiceParameterBuilder();
            string actual;

            actual = instance.Build("-f", typeof(bool), true);
            Assert.AreEqual("-f", actual);

            actual = instance.Build("-f", typeof(bool), false);
            Assert.IsNull(actual);
        }

        /// <summary>
        /// Tests the <see cref="ChoiceParameterBuilder.Build"/> method
        /// for the default parameter.
        /// </summary>
        [Test]
        [ExpectedException(typeof(NotSupportedException))]
        public static void BuildDefaultParameter()
        {
            ChoiceParameterBuilder instance = new ChoiceParameterBuilder();
            instance.Build(null, typeof(bool), true);
        }

        /// <summary>
        /// Tests the <see cref="ChoiceParameterBuilder.Build"/> method
        /// with a wrong property type.
        /// </summary>
        [Test]
        [ExpectedException(typeof(NotSupportedException))]
        public static void BuildWrongType()
        {
            ChoiceParameterBuilder instance = new ChoiceParameterBuilder();
            instance.Build("-f", typeof(string), "value");
        }
    }
}
