﻿/*
Copyright © 2010 François Karman

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

See <license.txt> for the complete license of the software.
*/

using System;
using NUnit.Framework;

namespace MSBuild.Mercurial.Command
{
    /// <summary>
    /// Tests the <see cref="DateParameterBuilder"/> class.
    /// </summary>
    [TestFixture]
    public static class DateParameterBuilderTest
    {
        /// <summary>
        /// Tests the <see cref="DateParameterBuilder.CanBuild"/> method.
        /// </summary>
        [Test]
        public static void CanBuild()
        {
            DateParameterBuilder instance = new DateParameterBuilder();
            Assert.IsTrue(instance.CanBuild(typeof(DateTime?)));
            Assert.IsFalse(instance.CanBuild(typeof(DateTime)));
            Assert.IsFalse(instance.CanBuild(typeof(string)));
            Assert.IsFalse(instance.CanBuild(null));
        }

        /// <summary>
        /// Tests the <see cref="DateParameterBuilder.Build"/> method.
        /// </summary>
        [Test]
        public static void Build()
        {
            DateParameterBuilder instance = new DateParameterBuilder();
            DateTime? reference = new DateTime(2000, 1, 2, 13, 4, 5);
            string expected = "\"2000-01-02 13:04:05\"";
            string actual;

            actual = instance.Build("-f", typeof(DateTime?), reference);
            Assert.AreEqual("-f " + expected, actual);

            actual = instance.Build(string.Empty, typeof(DateTime?), reference);
            Assert.AreEqual(expected, actual);

            actual = instance.Build(null, typeof(DateTime?), reference);
            Assert.AreEqual(expected, actual);

            actual = instance.Build("-f", typeof(DateTime?), null);
            Assert.IsNull(actual);

            actual = instance.Build(string.Empty, typeof(DateTime?), null);
            Assert.IsNull(actual);
        }

        /// <summary>
        /// Tests the <see cref="DateParameterBuilder.Build"/> method
        /// with a wrong property type.
        /// </summary>
        [Test]
        [ExpectedException(typeof(NotSupportedException))]
        public static void BuildWrongType()
        {
            DateParameterBuilder instance = new DateParameterBuilder();
            instance.Build("-f", typeof(bool), true);
        }
    }
}
