﻿/*
Copyright © 2010 François Karman

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

See <license.txt> for the complete license of the software.
*/

using System;
using Microsoft.Build.Framework;
using Microsoft.Build.Utilities;
using NUnit.Framework;

namespace MSBuild.Mercurial.Command
{
    /// <summary>
    /// Tests the <see cref="ItemsParameterBuilder"/> class.
    /// </summary>
    [TestFixture]
    public static class ItemsParameterBuilderTest
    {
        /// <summary>
        /// Tests the <see cref="ItemsParameterBuilder.CanBuild"/> method.
        /// </summary>
        [Test]
        public static void CanBuild()
        {
            ItemsParameterBuilder instance = new ItemsParameterBuilder();
            Assert.IsTrue(instance.CanBuild(typeof(ITaskItem[])));
            Assert.IsFalse(instance.CanBuild(typeof(ITaskItem)));
            Assert.IsFalse(instance.CanBuild(typeof(string[])));
            Assert.IsFalse(instance.CanBuild(typeof(string)));
            Assert.IsFalse(instance.CanBuild(null));
        }

        /// <summary>
        /// Tests the <see cref="ItemsParameterBuilder.Build"/> method.
        /// </summary>
        [Test]
        public static void Build()
        {
            ItemsParameterBuilder instance = new ItemsParameterBuilder();
            ITaskItem[] reference = new ITaskItem[]
            {
                new TaskItem("File1.cs"),
                new TaskItem("Dir\\File2.cs"),
            };
            string actual;

            actual = instance.Build(null, typeof(ITaskItem[]), reference);
            Assert.AreEqual("\"File1.cs\" \"Dir\\File2.cs\"", actual);

            actual = instance.Build(null, typeof(ITaskItem[]), new ITaskItem[] { });
            Assert.IsNull(actual);

            actual = instance.Build(null, typeof(ITaskItem[]), null);
            Assert.IsNull(actual);
        }

        /// <summary>
        /// Tests the <see cref="ItemsParameterBuilder.Build"/> method
        /// with a wrong property type.
        /// </summary>
        [Test]
        [ExpectedException(typeof(NotSupportedException))]
        public static void BuildWrongType()
        {
            ItemsParameterBuilder instance = new ItemsParameterBuilder();
            instance.Build("-f", typeof(bool), true);
        }
    }
}
