﻿/*
Copyright © 2010 François Karman

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

See <license.txt> for the complete license of the software.
*/

using System;
using NUnit.Framework;

namespace MSBuild.Mercurial.Command
{
    /// <summary>
    /// Tests the <see cref="StringParameterBuilder"/> class.
    /// </summary>
    [TestFixture]
    public static class StringParameterBuilderTest
    {
        /// <summary>
        /// Tests the <see cref="StringParameterBuilder.Escape"/> method.
        /// </summary>
        [Test]
        public static void Escape()
        {
            Assert.AreEqual(null, StringParameterBuilder.Escape(null));
            Assert.AreEqual(string.Empty, StringParameterBuilder.Escape(string.Empty));
            Assert.AreEqual("\"value\"", StringParameterBuilder.Escape("value"));
            Assert.AreEqual("\"my value\"", StringParameterBuilder.Escape("my value"));
            Assert.AreEqual("\"my \\ \\\" value\"", StringParameterBuilder.Escape("my \\ \" value"));
        }

        /// <summary>
        /// Tests the <see cref="StringParameterBuilder.CanBuild"/> method.
        /// </summary>
        [Test]
        public static void CanBuild()
        {
            StringParameterBuilder instance = new StringParameterBuilder();
            Assert.IsTrue(instance.CanBuild(typeof(string)));
            Assert.IsFalse(instance.CanBuild(typeof(bool)));
            Assert.IsFalse(instance.CanBuild(null));
        }

        /// <summary>
        /// Tests the <see cref="StringParameterBuilder.Build"/> method.
        /// </summary>
        [Test]
        public static void Build()
        {
            StringParameterBuilder instance = new StringParameterBuilder();
            string actual;

            actual = instance.Build("-f", typeof(string), "value");
            Assert.AreEqual("-f \"value\"", actual);

            actual = instance.Build(string.Empty, typeof(string), "value");
            Assert.AreEqual("\"value\"", actual);

            actual = instance.Build(null, typeof(string), "value");
            Assert.AreEqual("\"value\"", actual);

            actual = instance.Build("-f", typeof(string), string.Empty);
            Assert.IsNull(actual);

            actual = instance.Build(string.Empty, typeof(string), string.Empty);
            Assert.IsNull(actual);

            actual = instance.Build(null, typeof(string), "my \\ \" value");
            Assert.AreEqual("\"my \\ \\\" value\"", actual);
        }

        /// <summary>
        /// Tests the <see cref="StringParameterBuilder.Build"/> method
        /// with a wrong property type.
        /// </summary>
        [Test]
        [ExpectedException(typeof(NotSupportedException))]
        public static void BuildWrongType()
        {
            StringParameterBuilder instance = new StringParameterBuilder();
            instance.Build("-f", typeof(bool), true);
        }
    }
}
