﻿/*
Copyright © 2010 François Karman

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

See <license.txt> for the complete license of the software.
*/

using NUnit.Framework;

namespace MSBuild.Mercurial
{
    /// <summary>
    /// Tests the <see cref="HgInit"/> class.
    /// </summary>
    [TestFixture]
    public static class HgInitTest
    {
        /// <summary>
        /// Deletes the created repository.
        /// </summary>
        [TearDown]
        public static void TearDown()
        {
            Repository.Delete();
        }

        /// <summary>
        /// Tests the <see cref="HgInit.Destination"/> property.
        /// </summary>
        [Test]
        public static void Destination()
        {
            HgInit instance = new HgInit();
            Assert.IsNull(instance.Destination);

            instance.LocalPath = "my path";
            Assert.AreEqual("my path", instance.Destination);

            instance.Destination = "my path 2";
            Assert.AreEqual("my path 2", instance.LocalPath);
        }

        /// <summary>
        /// Tests the <c>HgInit.Execute</c> method.
        /// </summary>
        [Test]
        public static void Execute()
        {
            HgInit instance = new HgInit();
            instance.BuildEngine = new MockBuildEngine();
            instance.LocalPath = Repository.FullPath;

            bool result = instance.Execute();

            Assert.IsTrue(result);
            string[] output = Repository.Execute("summary");
            OutputAssert.Contains(output, "parent:", "-1:");
        }
    }
}
