﻿/*
Copyright © 2010 François Karman

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

See <license.txt> for the complete license of the software.
*/

using NUnit.Framework;

namespace MSBuild.Mercurial
{
    /// <summary>
    /// Tests the <see cref="HgPush"/> class.
    /// </summary>
    [TestFixture]
    public static class HgPushTest
    {
        /// <summary>
        /// Initializes a repository used to test the HgPush task.
        /// </summary>
        [SetUp]
        public static void SetUp()
        {
            Repository.Create();
            Repository.Create2();
        }

        /// <summary>
        /// Deletes the repository used for the tests.
        /// </summary>
        [TearDown]
        public static void TearDown()
        {
            Repository.Delete();
        }

        /// <summary>
        /// Tests the <c>HgPush.Execute</c> method on local repository.
        /// </summary>
        [Test]
        public static void ExecuteLocal()
        {
            HgPush instance = new HgPush();
            instance.BuildEngine = new MockBuildEngine();
            instance.LocalPath = Repository.FullPath;
            instance.Destination = Repository.FullPath2;

            string[] output;

            output = Repository.Execute2("summary");
            OutputAssert.Contains(output, "parent:", "-1:");

            Assert.IsTrue(instance.Execute());

            Repository.Execute2("update");
            output = Repository.Execute2("summary");
            OutputAssert.Contains(output, "parent:", "0:");
        }

        /// <summary>
        /// Tests the <c>HgPush.Execute</c> method on remote repository.
        /// </summary>
        [Test]
        public static void ExecuteRemote()
        {
            MockRemoteRepository.ResetEmptyRepository();
            HgPush instance = new HgPush();
            instance.BuildEngine = new MockBuildEngine();
            instance.LocalPath = Repository.FullPath;
            instance.Destination = MockRemoteRepository.RepositoryUrl;
            instance.User = "test-write";
            instance.Password = "test";

            string[] output;

            output = MockRemoteRepository.Execute("summary");
            OutputAssert.Contains(output, "parent:", "-1:");

            Assert.IsTrue(instance.Execute());

            MockRemoteRepository.Execute("update");
            output = MockRemoteRepository.Execute("summary");
            OutputAssert.Contains(output, "parent:", "0:");
        }
    }
}
