﻿/*
Copyright © 2010 François Karman

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

See <license.txt> for the complete license of the software.
*/

using System;
using NUnit.Framework;

namespace MSBuild.Mercurial
{
    /// <summary>
    /// Tests the <see cref="HgVersion"/> class.
    /// </summary>
    [TestFixture]
    public static class HgVersionTest
    {
        /// <summary>
        /// Tests the <c>HgVersion.Execute</c> method.
        /// </summary>
        [Test]
        public static void Execute()
        {
            HgVersion instance = new HgVersion();
            instance.BuildEngine = new MockBuildEngine();
            instance.LocalPath = Environment.CurrentDirectory;

            bool result = instance.Execute();

            Assert.IsTrue(result);
            Assert.Greater(instance.Revision, 1);
            Assert.IsNotNullOrEmpty(instance.Changeset);
        }

        /// <summary>
        /// Tests the<c>HgVersion.Execute</c> method
        /// with a wrong path for Mercurial tools.
        /// </summary>
        [Test]
        public static void ExecuteWrongLibraryPath()
        {
            HgVersion instance = new HgVersion();
            instance.BuildEngine = new MockBuildEngine();
            instance.LocalPath = Environment.CurrentDirectory;
            instance.LibraryLocation = "c:\\";

            bool result = instance.Execute();

            Assert.IsFalse(result);
        }

        /// <summary>
        /// Tests the<c>HgVersion.Execute</c> method
        /// on a directory that is not a Mercurial workspace.
        /// </summary>
        [Test]
        public static void ExecuteWrongLocalPath()
        {
            HgVersion instance = new HgVersion();
            instance.BuildEngine = new MockBuildEngine();
            instance.LocalPath = "c:\\";

            bool result = instance.Execute();

            Assert.IsFalse(result);
        }
    }
}
