﻿/*
Copyright © 2010 François Karman

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

See <license.txt> for the complete license of the software.
*/

using System;

namespace MSBuild.Mercurial
{
    /// <summary>
    /// Implements the <see cref="AbstractHgTask"/> class
    /// for testing purpose.
    /// </summary>
    /// <remarks>
    /// This task is not related to Mercurial and is not
    /// associated to any command.
    /// </remarks>
    [Command("mock")]
    internal class MockTask : AbstractHgTask
    {
        /// <summary>
        /// Gets or sets a value indicating whether the boolean parameter is set.
        /// </summary>
        [Parameter("bool")]
        public bool BoolParameter { get; set; }

        /// <summary>
        /// Gets or sets a string parameter.
        /// </summary>
        [Parameter("string")]
        public string StringParameter { get; set; }

        /// <summary>
        /// Gets or sets a date-time parameter.
        /// </summary>
        [Parameter("date")]
        public DateTime? DateTimeParameter { get; set; }

        /// <summary>
        /// Gets or sets the default parameter.
        /// </summary>
        [Parameter("")]
        public string DefaultParameter { get; set; }

        /// <summary>
        /// Does nothing and always returns <c>false</c>.
        /// </summary>
        /// <returns>
        /// Always returns <c>false</c>.
        /// </returns>
        public override bool Execute()
        {
            return false;
        }
    }
}
