﻿/*
Copyright © 2010 François Karman

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

See <license.txt> for the complete license of the software.
*/

using System;
using NUnit.Framework;

namespace MSBuild.Mercurial.CodePlex
{
    /// <summary>
    /// Tests the <see cref="DocumentationBuilder"/> class.
    /// </summary>
    [TestFixture]
    public static class DocumentationBuilderTest
    {
        /// <summary>
        /// Test the <see cref="DocumentationBuilder.CreateDocumentation(Type)"/> method.
        /// </summary>
        [Test]
        public static void CreateDocumentationType()
        {
            TaskDocumentation actual = DocumentationBuilder.CreateDocumentation(typeof(MockTask));

            Assert.IsNotNull(actual);
            Assert.AreEqual("MockTask", actual.Name);
            Assert.AreEqual(3, actual.Properties.Count);
        }

        /// <summary>
        /// Test the <see cref="DocumentationBuilder.CreateDocumentation(System.Reflection.PropertyInfo)"/> method.
        /// </summary>
        [Test]
        public static void CreateDocumentationProperty()
        {
            Type reference = typeof(MockTask);
            PropertyDocumentation actual;

            // Valid the StringParameter property
            actual = DocumentationBuilder.CreateDocumentation(reference.GetProperty("StringParameter"));
            Assert.IsNotNull(actual);
            Assert.IsNotNull(actual.Comment);
            Assert.AreEqual("StringParameter", actual.Name);
            Assert.AreEqual(true, actual.Required);
            Assert.AreEqual("string", actual.Type);
            Assert.AreEqual("-s", actual.Parameter);
            StringAssert.StartsWith("<member name=\"P:MSBuild.Mercurial.CodePlex.MockTask.StringParameter\"><summary>", actual.Comment.OuterXml);
            StringAssert.Contains("Gets or sets a string parameter.", actual.Comment.OuterXml);
            StringAssert.EndsWith("</summary></member>", actual.Comment.OuterXml);

            // Valid the ChoiceParameter property
            actual = DocumentationBuilder.CreateDocumentation(reference.GetProperty("ChoiceParameter"));
            Assert.IsNotNull(actual);
            Assert.IsNotNull(actual.Comment);
            Assert.AreEqual("ChoiceParameter", actual.Name);
            Assert.AreEqual(false, actual.Required);
            Assert.AreEqual("choice", actual.Type);
            Assert.AreEqual("-c", actual.Parameter);
            StringAssert.StartsWith("<member name=\"P:MSBuild.Mercurial.CodePlex.MockTask.ChoiceParameter\"><summary>", actual.Comment.OuterXml);
            StringAssert.Contains("Gets or sets a value indicating whether the choice is set.", actual.Comment.OuterXml);
            StringAssert.EndsWith("</summary></member>", actual.Comment.OuterXml);

            // Valid the DateParameter property
            actual = DocumentationBuilder.CreateDocumentation(reference.GetProperty("DateParameter"));
            Assert.IsNotNull(actual);
            Assert.IsNotNull(actual.Comment);
            Assert.AreEqual("DateParameter", actual.Name);
            Assert.AreEqual(false, actual.Required);
            Assert.AreEqual("date", actual.Type);
            Assert.AreEqual("-d", actual.Parameter);
            StringAssert.StartsWith("<member name=\"P:MSBuild.Mercurial.CodePlex.MockTask.DateParameter\"><summary>", actual.Comment.OuterXml);
            StringAssert.Contains("Gets or sets a date parameter.", actual.Comment.OuterXml);
            StringAssert.EndsWith("</summary></member>", actual.Comment.OuterXml);

            // Valid the BuildEngine property
            actual = DocumentationBuilder.CreateDocumentation(reference.GetProperty("BuildEngine"));
            Assert.IsNull(actual);

            // Valid the HostObject property
            actual = DocumentationBuilder.CreateDocumentation(reference.GetProperty("HostObject"));
            Assert.IsNull(actual);
        }
    }
}
