﻿/*
Copyright © 2010 François Karman

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

See <license.txt> for the complete license of the software.
*/

using System;
using System.Xml;
using NUnit.Framework;

namespace MSBuild.Mercurial.CodePlex
{
    /// <summary>
    /// Tests the <see cref="MemberInfoExtensions"/> class.
    /// </summary>
    [TestFixture]
    public static class MemberInfoExtensionsTest
    {
        /// <summary>
        /// Tests the <see cref="MemberInfoExtensions.Comment"/> method
        /// on a type.
        /// </summary>
        [Test]
        public static void CommentType()
        {
            XmlNode actual = typeof(DocumentedClass).Comment();

            Assert.IsNotNull(actual);
            StringAssert.StartsWith("<member name=\"T:MSBuild.Mercurial.CodePlex.DocumentedClass\"><summary>", actual.OuterXml);
            StringAssert.Contains("Summary of the DocumentedClass class.", actual.OuterXml);
            StringAssert.EndsWith("</remarks><seealso cref=\"T:MSBuild.Mercurial.CodePlex.MemberInfoExtensionsTest\" /></member>", actual.OuterXml);
        }

        /// <summary>
        /// Tests the <see cref="MemberInfoExtensions.Comment"/> method
        /// on a property.
        /// </summary>
        [Test]
        public static void CommentProperty()
        {
            XmlNode actual = typeof(DocumentedClass).GetProperty("Property").Comment();

            Assert.IsNotNull(actual);
            StringAssert.StartsWith("<member name=\"P:MSBuild.Mercurial.CodePlex.DocumentedClass.Property\"><summary>", actual.OuterXml);
            StringAssert.Contains("Gets or sets a value.", actual.OuterXml);
            StringAssert.EndsWith("</summary></member>", actual.OuterXml);
        }
    }
}
