﻿/*
Copyright © 2010 François Karman

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

See <license.txt> for the complete license of the software.
*/

using System.Globalization;
using System.IO;
using System.Xml.Serialization;
using NUnit.Framework;

namespace MSBuild.Mercurial.CodePlex
{
    /// <summary>
    /// Tests the <see cref="TaskDocumentation"/> class.
    /// </summary>
    [TestFixture]
    public static class TaskDocumentationTest
    {
        /// <summary>
        /// Tests the <see cref="TaskDocumentation.Properties"/> property.
        /// </summary>
        [Test]
        public static void Properties()
        {
            TaskDocumentation instance = new TaskDocumentation();
            Assert.IsNotNull(instance.Properties);
            Assert.IsEmpty(instance.Properties);
        }

        /// <summary>
        /// Tests the Xml serialization of an empty object.
        /// </summary>
        [Test]
        public static void XmlEmpty()
        {
            TaskDocumentation instance = new TaskDocumentation();

            XmlSerializer serializer = new XmlSerializer(typeof(TaskDocumentation));
            StringWriter writer = new StringWriter(CultureInfo.CurrentCulture);
            serializer.Serialize(writer, instance);

            Assert.IsNotNull(writer);
            StringAssert.Contains("<TaskDocumentation ", writer.ToString());
            StringAssert.Contains("</TaskDocumentation>", writer.ToString());
        }

        /// <summary>
        /// Tests the Xml serialization of an initialized object.
        /// </summary>
        /// <remarks>
        /// This unit test is based on <see cref="DocumentationBuilder"/> and could
        /// failed if this class doesn't work perfectly.
        /// </remarks>
        [Test]
        public static void XmlInitialized()
        {
            TaskDocumentation instance = DocumentationBuilder.CreateDocumentation(typeof(MockTask));

            XmlSerializer serializer = new XmlSerializer(typeof(TaskDocumentation));
            StringWriter writer = new StringWriter(CultureInfo.CurrentCulture);
            serializer.Serialize(writer, instance);

            Assert.IsNotNull(writer);
            StringAssert.Contains("<TaskDocumentation ", writer.ToString());
            StringAssert.Contains("<PropertyDocumentation>", writer.ToString());
            StringAssert.Contains("</TaskDocumentation>", writer.ToString());
        }
    }
}
